Index: src/compiler/js-generic-lowering.cc |
diff --git a/src/compiler/js-generic-lowering.cc b/src/compiler/js-generic-lowering.cc |
index ab4a7bb8d29eb31fd39db68a4d1c5c8b2d8de2b7..25f6414f5c28f88674788864003c2878f38adf63 100644 |
--- a/src/compiler/js-generic-lowering.cc |
+++ b/src/compiler/js-generic-lowering.cc |
@@ -479,8 +479,9 @@ void JSGenericLowering::LowerJSCreateFunctionContext(Node* node) { |
int const slot_count = OpParameter<int>(node->op()); |
CallDescriptor::Flags flags = AdjustFrameStatesForCall(node); |
- // Use the FastNewContextStub only for function contexts up maximum size. |
- if (slot_count <= FastNewContextStub::kMaximumSlots) { |
+ // Use the FastNewFunctionContextStub only for function contexts up maximum |
+ // size. |
+ if (slot_count <= FastNewFunctionContextStub::kMaximumSlots) { |
Callable callable = CodeFactory::FastNewContext(isolate(), slot_count); |
ReplaceWithStubCall(node, callable, flags); |
} else { |